%global momorel 1

Summary: packet-sniffer/logger
Name: snort
Version: 2.1.3
Release: %{momorel}m
License: GPL
Group: Applications/Internet
#Source0: http://www.snort.org/dl/old/snort-%{version}.tar.gz
Source0: http://www.snort.org/dl/snort-%{version}.tar.gz
NoSource: 0
Source1: snortd
URL: http://www.snort.org/
Buildroot: %{_tmppath}/%{name}-%{version}-root
BuildRequires: libpcap >= 0.8.3
BuildRequires: MySQL-devel
BuildRequires: pcre-devel
BuildRequires: postgresql-devel

%description
Snort is a libpcap-based packet sniffer/logger which can be used as a
lightweight network intrusion detection system.  It features rules based
logging and can perform protocol analysis, content searching/matching
and can be used to detect a variety of attacks and probes, such as
buffer overflows, stealth port scans, CGI attacks, SMB probes, OS
fingerprinting attempts, and much more.  Snort has a real-time alerting
capabilty, with alerts being sent to syslog, a seperate "alert" file, or
as a WinPopup message via Samba's smbclient

%prep
%setup -q

%build
%configure --bindir=%{_sbindir} --sysconfdir=/etc/snort --enable-smbalerts --with-postgresql --with-mysql
%make
perl -p -i -e 's,^var RULE_PATH.*$,var RULE_PATH ./,' etc/snort.conf

%install
rm -rf %{buildroot}
mkdir -p %{buildroot}/etc/snort
mkdir -p %{buildroot}/var/log/snort/archive
mkdir -p %{buildroot}%{_initscriptdir}
mkdir -p %{buildroot}%{_mandir}/man8

%makeinstall bindir=%{buildroot}%{_sbindir}

for i in rules/*.rules ;
  do install $i %{buildroot}/etc/snort ;
done
install %{SOURCE1} %{buildroot}%{_initscriptdir}
install etc/* %{buildroot}/etc/snort
rm -f %{buildroot}/etc/snort/Makefile*
install %{name}.8 %{buildroot}%{_mandir}/man8
rm -rf doc/Makefile* contrib/Makefile* contrib/rpm
chmod -x contrib/*

%clean
rm -rf %{buildroot}

%pre
if ! grep -q '^snort:' /etc/group; then
  /usr/sbin/groupadd -r snort
fi
if ! grep -q '^snort:' /etc/passwd; then
  /usr/sbin/useradd -M -r -d /var/log/snort -s /bin/false -g snort -c "Snort" snort || :
fi

%post
/sbin/chkconfig --add snortd
echo -e "
Be sure to fetch the latest snort rules file from the ArachNIDS
database by Max Vision, or the one available from the snort.org web
site.

The snortlog and snort-stat perl scripts can be used to generate
statistics from the snort syslog entries.

Snort is currently configured to listen only on eth0, and uses the
default rulesets. If this is not correct for your system, edit
/etc/init.d/snortd and /etc/snort/snort.conf
"

%preun
if [ -f /var/lock/subsys/snortd ] ; then
  %{_initscriptdir}/snortd stop
fi
if [ $1 = 0 ] ; then
  /sbin/chkconfig --del snortd
fi

%postun
if [ $1 = 0 ]; then
  if [ `grep snort /etc/passwd | wc -l` = 1 ]; then
    /usr/sbin/userdel snort
  fi
  if [ `grep snort /etc/group | wc -l` = 1 ]; then
    /usr/sbin/groupdel snort
  fi
fi

%files
%defattr(-,root,root)
%doc COPYING ChangeLog LICENSE doc/* contrib
%attr(750,root,root) %config(noreplace) %{_initscriptdir}/snortd
%attr(640,snort,snort) %config(noreplace) /etc/snort/snort.conf
%attr(640,snort,snort) %config /etc/snort/*.rules
%attr(640,snort,snort) %config /etc/snort/*.config
%attr(640,snort,snort) %config /etc/snort/threshold.conf
%attr(640,snort,snort) %config /etc/snort/*.map
%attr(640,snort,snort) %config /etc/snort/generators
%attr(640,snort,snort) %config /etc/snort/sid
%{_sbindir}/*
%attr(750,snort,snort) /var/log/snort
%{_mandir}/man8/%{name}*

%changelog
* Wed Jun  9 2004 IWAMOTO Kazuya <iwapi@momonga-linux.org>
- (2.1.3-1m)
- update to 2.1.3

* Wed Apr  7 2004 Kazuhiko <kazuhiko@fdiary.net>
- (2.1.2-1m)
- bugfix release

* Fri Dec 19 2003 Kazuhiko <kazuhiko@fdiary.net>
- (2.1.0-2m)
- add missing files

* Fri Dec 19 2003 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.1.0-1m)
- update to 2.1.0
- add BuildRequires: pcre-devel for use prce.h
- add BuildRequires: postgresql-devel

* Tue Dec  9 2003 Kazuhiko <kazuhiko@fdiary.net>
- (2.0.5-1m)

* Fri Nov  7 2003 Kazuhiko <kazuhiko@fdiary.net>
- (2.0.4-1m)

* Wed Nov  5 2003 Kazuhiko <kazuhiko@fdiary.net>
- (2.0.3-1m)

* Sat Sep 20 2003 Kazuhiko <kazuhiko@fdiary.net>
- (2.0.2-1m)

* Wed Sep 10 2003 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.0.1-3m)
- add BuildRequires: MySQL

* Thu Sep  4 2003 Kazuhiko <kazuhiko@fdiary.net>
- (2.0.1-2m)
- rebuild against MySQL-4.0.14

* Tue Aug 12 2003 Kikutani Makoto <poo@momonga-linux.org>
- (2.0.1-1m)
- new upstream version
- remove create_postgresql.patch

* Mon Jul 21 2003 Kazuhiko <kazuhiko@fdiary.net>
- (2.0.0-2m)
- rebuild against glibc-2.3.2                               

* Thu Apr 17 2003 Shigeyuki Yamashita <shige@cty-net.ne.jp>
- (2.0.0-1m)
- security update
  TCP Stream Reassembly Integer Overflow Vulnerability
  (reference: http://www.coresecurity.com/common/showdoc.php?idx=313&idxseccion=10)

* Sat Mar 15 2003 Kikutani Makoto <poo@momonga-linux.org>
- (1.9.1-3m)
- create_postgresql.patch for postgresql-7.3.x

* Sun Mar  8 2003 Tsutomu Yasuda <tom@tom.homelinux.org>
- (1.9.1-2m)
  rebuild against openssl 0.9.7a

* Tue Mar  4 2003 Kazuhiko <kazuhiko@fdiary.net>
- (1.9.1-1m)
- fixes vulnerability in rpc decoder

* Thu Jan 23 2003 Shingo Akagaki <dora@kitty.dnsalias.org>
- (1.9.0-2m)
- rebuild against for postgresql

* Sat Oct  5 2002 Kazuhiko <kazuhiko@fdiary.net>
- (1.9.0-1m)

* Tue Aug 13 2002 Kikutani <poo@momonga-linux.org>
- (1.8.7-3m)
- added man page

* Mon Jul 22 2002 Kikutani <poo@momonga-linux.org>
- (1.8.7-2m)
- added --with-postgresql --with-mysql for %configure
- added contrib/create* *.pdf for %doc

* Mon Jul 22 2002 Kazuhiko <kazuhiko@fdiary.net>
- (1.8.7-1m)

* Sat Jul  6 2002 Kazuhiko <kazuhiko@fdiary.net>
- (1.8.6-1m)
